package com.pm.enterpriseInfo.service;

import com.pm.common.config.PageData;

import java.util.List;

public interface IEnterpriseService {

    public List<PageData> selectEnterpriseList(PageData pd);

    public PageData selectEnterpriseByEnterpriseId(Long enterpriseId);

    public int insertEnterprise(PageData pd);

    public int updateEnterprise(PageData pd);

    public int deleteEnterpriseByEnterpriseIds(Long[] enterpriseIds);

    public int deleteEnterpriseByEnterpriseId(Long enterpriseId);

    PageData getEnterpriseStatistics();
}
